
#################################

rm(list=ls())
source("functions.R")
library(lmer)
library(lmerTest)
library(effects)
library(ggplot2)
library(ggbreak)
logit2prob <- function(logit){odds <- exp(logit); prob <- odds/(1+odds); return(prob)}

#################################

# Esempio LM Score-Et

N<-200
d<-data.frame(Age=runif(N,30,90),Acc=NA,Score=NA)
d$Acc<-logit2prob(-(d$Age-min(d$Age))/8+.6*rnorm(N,0,1))
d$Score<-round(d$Acc*30)
x<-lm(d$Score~d$Age)
sd(residuals(x))
summary(x)
ggplot(data=d,aes(y=Score,x=Age)) +geom_point(size=5,alpha=.4)+
  theme(axis.title=element_text(size=25),axis.text=element_text(size=25),panel.grid.minor=element_blank())+
  geom_smooth(method='lm',se=F,size=2,fullrange=T,col="red")+
  scale_x_continuous(limits=c(0,max(d$Age)),breaks=c(0,seq(30,100,10)))
  
#################################

# Green-Benessere

N<-50; k<-8
d<-data.frame(ID=1:(N*k),q=rep(letters[1:k],each=N),green=NA,wb=NA)
d$wb<-c(rep(2.2,N),rep(rnorm(k-1),each=N))+rnorm(N*k,0,.5)
d$green<-c(rep(2.2,N),rep(rnorm(k-1),each=N))+rnorm(N*k,0,.5)

ggplot(data=d,aes(y=wb,x=green,color=q))+
  #geom_smooth(method='lm',se=F,size=2,fullrange=T,col="red")+
  geom_point(size=4,alpha=.7)+
  scale_x_continuous(breaks=seq(-5,5,1))+scale_y_continuous(breaks=seq(-5,5,1))+
  theme(axis.title=element_text(size=25),axis.text=element_text(size=25),panel.grid.minor=element_blank(),legend.position="none")+
  xlab("Perceived green (z)")+ylab("Well-being (z)")

x<-lmer(wb~green+(green|q),data=d)
summary(x)  
ranef(x)

#################################

# IAPS pos-neg

Nsubj<-6
nrep<-50
d<-data.frame(id=rep(letters[1:Nsubj],nrep*2),Condition=rep(c("Neut","Neg"),each=Nsubj*nrep,times=2))
d$item<-rep(1:nrep,each=Nsubj)
d$rInt<-rep(rnorm(Nsubj,0,.5),times=nrep*2)
d$Sweat<-d$rInt+rnorm(Nsubj*nrep*2,0,.5)
d$Sweat[d$id==letters[Nsubj]&d$Condition=="Neg"]<-d$Sweat[d$id==letters[Nsubj]&d$Condition=="Neg"]+1.5
d$Condition<-factor(d$Condition,levels=c("Neut","Neg"))

ggplot(data=d,aes(x=id,y=Sweat,color=Condition,fill=Condition))+geom_boxplot(size=1)+
  scale_fill_manual(values=c("#888888","#FF5555"))+
  scale_color_manual(values=c("#000000","#880000"))+
  theme(axis.title=element_text(size=25),axis.text=element_text(size=25),panel.grid.minor=element_blank())+
  xlab("Subject")+ylab("Sudorazione")

# Only intercept
fit<-lmer(Sweat~Condition+(1|id)+(1|item),data=d)
summary(fit)
ranef(fit)

# Intercept and slope
fit<-lmer(Sweat~Condition+(1+Condition|id)+(1|item),data=d)
summary(fit)
ranef(fit)

# Visualize random effects
source("functions.R")
ggCaterpillar(ranef(fit, condVar=TRUE), QQ=FALSE)

#################################

